# Miscellaneous

::: survey_kit.serializable.Serializable
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2

::: survey_kit.utilities.dataframe_list.DataFrameList
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2

::: survey_kit.utilities.compress.compress_df
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2

::: survey_kit.utilities.random
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2

::: survey_kit.utilities.formula_builder.FormulaBuilder
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2